Learn R Programming

LSMonteCarlo (version 1.0)

AmerPutLSMPriceSurf: Deriving a table of American put prices at different volatilities and strikes

Description

The function calculates the prices at different volatilities and strikes using the AmerPutLSM function.

Usage

AmerPutLSMPriceSurf(Spot = 1, vols = (seq(0.1, 2, 0.1)), n = 1000, m = 365, strikes = (seq(0.5, 2.5, 0.1)), r = 0.06, dr = 0, mT = 1)
"summary"(object, ...) "plot"(x, color = divPalette(800, "RdBu"), ...)

Arguments

Spot
Spot price of the underlying asset (e.g. stock).
vols
Sequence of volatilities.
n
Number of paths simulated.
m
Number of time steps in the simulation.
strikes
Sequence of strikes.
r
Interest rate of the numeraire currency (e.g. EUR).
dr
Dividend rate of the underlying asset.
mT
Maturity time (years).
object
Object of the class PriceSurface that is a matrix of prices at different volatilities and strikes.
x
Object of the class PriceSurface that is a matrix of prices at different volatilities and strikes.
color
Color palette (the default pallet requires package fBasics, if you do not want to load this package, you can set color=NULL or other palette).
...
Not used.

Value

The function returns an object of the class PriceSurface that is a matrix of prices at different volatilities and strikes. Class-specific summary function gives the sequences of volatilities and strikes used, as well as maximum, minimum, and average prices. Class-specific plot function constructs a 3-D plot of the price surface.

See Also

Functions: AmerPutLSM, AsianAmerPutLSMPriceSurf, and QuantoAmerPutLSMPriceSurf.

Examples

Run this code
surface<-AmerPutLSMPriceSurf(vols = (seq(0.1, 1.5, 0.2)), n=200, m=10, 
strikes = (seq(0.5, 1.9, 0.2)))
summary(surface)
plot(surface, color = divPalette(150, "RdBu"))

Run the code above in your browser using DataLab