QuantoAmerPutLSM(Spot = 1, sigma = 0.2, n = 1000, m = 365, Strike = 1.1, r = 0.06,
dr = 0, mT = 1, Spot2 = 1, sigma2 = 0.2, r2 = 0, dr2 = 0, rho = 0)
"print"(x, ...)
"summary"(object, ...)QuantoAmerPutLSM. QuantoAmerPutLSM. print function gives the option type information and the price. The price as a single number can be derived using the price function. An overview of the entire object can be seen using the summary function.
Vecer, J. 2011. Stochastic Finance: A Numeraire Approach. CRC Press.
Wystup, U. 2011. Quanto Options. MathFinance AG.
price,
QuantoAmerPutLSM_AV,
AmerPutLSM,
AsianAmerPutLSM, and
AmerPutLSM_AV.
QuantoAmerPutLSM(n=200, m=50)
put<-QuantoAmerPutLSM(Spot=14.2, Strike=16.5, n=200, m=50)
put
summary(put)
price(put)
Run the code above in your browser using DataLab